@@ -188,15 +188,14 @@ class WWULogo:
 
 
 def _example():
-    import gdsCAD.core
-    from gdshelpers.geometry import convert_to_gdscad
+    from gdshelpers.geometry.chip import Cell
 
     kit_logo = KITLogo([0, 0], 1)
     wwu_logo = WWULogo([0, 0], 1, 1)
 
-    cell = gdsCAD.core.Cell('LOGOS')
-    cell.add(convert_to_gdscad(kit_logo))
-    cell.add(convert_to_gdscad(translate(wwu_logo.get_shapely_object(), 2.5)))
+    cell = Cell('LOGOS')
+    cell.add_to_layer(1, kit_logo)
+    cell.add_to_layer(1, translate(wwu_logo.get_shapely_object(), 2.5))
     cell.show()
 
 
